# Devices

Modules that interact with the EM fields of the simulation. This includes injecting (sources), detecting (monitors), and other kinds of regional field manipulation (boundaries) that don't stem from the design or its materials themselves.

+ core.py       / Main module that defines ...
+ boundaries/
    + pml.py
+ monitors/
    + ...
+ sources/
    + ...